import sys
import shutil
import getpass
import time
from tqdm import tqdm as pb
import telegrambot
import os

args = sys.argv


class module_uninstaller:
    def uninstall():
        print("Telegram Bot Library Module Uninstaller")
        print("***************************************")
        print()

        try:

            pathforpackages = "C:/Users/" + getpass.getuser() + \
                "/AppData/Local/Programs/Python/Python38-32/Lib/site-packages/"

            print("Do you really want to uninstall this module?")
            ok = input("(y/n): ")

            if ok == "y":
                progressbar = pb(range(2), desc="Uninstalling Module")
                progressbar.update(1)
                shutil.rmtree(pathforpackages + "telegrambot")
                progressbar.update(1)
                progressbar.close()
                print("Sucessfully Uninstalled.")
                time.sleep(5)
            else:
                quit()
        except:
            print("There was an error. This could be because you don't operate Windows (10). This installer was only tested on Windows and it could raise errors in other operating systems. Please try it again or create an issue on GitHub.")


if len(args) > 1:
    if args[1] == "--help":
        print(os.getcwd())
        helpdocspath = telegrambot.__file__.replace(
            "__init__.py", "helpdocs.txt")
        helpdocsfile = open(helpdocspath, "r")
        helpdocs = helpdocsfile.read()
        helpdocsfile.close()
        print(helpdocs)

    if args[1] == "--uninstall":
        module_uninstaller.uninstall()



import shutil
import os
from tqdm import tqdm as pb
import time
import getpass

os.chdir("C:/Users/" + getpass.getuser() + "/OneDrive/Programme, Elektronik und Projekte/Python/python-telegram-api")

files_for_archiving = ["LICENSE", "README.md", "__main__.py",
                       "__init__.py", "helpdocs.txt"]
dirs_for_archiving = ["module_file/module_uninstaller"]

pbRange = len(files_for_archiving) + len(dirs_for_archiving) + 5
progressbar = pb(range(pbRange), desc="Archiving Module")

i = 0
try:
    shutil.rmtree("module")
except:
    pass
os.mkdir("module")
progressbar.update(1)
progressbar.update(1)
for x in files_for_archiving:
    shutil.copyfile(files_for_archiving[i],
                    "module/" + files_for_archiving[i])
    i = i + 1
    progressbar.update(1)

i = 0
for x in dirs_for_archiving:
    shutil.copytree(dirs_for_archiving[i],
                    "module/" + dirs_for_archiving[i])
    i = i + 1
    progressbar.update(1)

os.remove("module.tar")
progressbar.update(1)
shutil.make_archive("module", "tar", root_dir="module/")
progressbar.update(1)
shutil.rmtree("module")
progressbar.update(1)
progressbar.close()

time.sleep(3)



import shutil
import os
import getpass
import time
from tqdm import tqdm as pb

print("Telegram Bot Library Module Installer")
print("*************************************")
print()

try:
    old_cwd = os.getcwdb()

    pathforpackages = "C:/Users/" + getpass.getuser() + \
        "/AppData/Local/Programs/Python/Python38-32/Lib/site-packages/"

    override_ok = 0
    try:
        os.chdir(pathforpackages + "telegrambot")
        os.chdir("C:/")
        print(
            "There is already package with this name. Would you like to override it?")
        override = input("(y/n): ")
        if override == "y":
            override_ok = 1
            #shutil.rmtree(pathforpackages + "telegrambot")
        else:
            pass
    except FileNotFoundError:
        override_ok = 1

    if override_ok == 1:
        progressbar = pb(range(2), desc="Installing Module")
        
        old_path = old_cwd.decode()
        progressbar.update(1)
        shutil.unpack_archive(old_path + "/module.tar", extract_dir=pathforpackages + "telegrambot")
        progressbar.update(1)
        progressbar.close()
        print("Sucessfully Installed.\nYou can import the module with 'import telegrambot' now\nIf you need help, simply type 'python -m telegrambot --help' to the system shell.")
        time.sleep(5)
except:
    print("There was an error. This could be because you don't operate Windows (10). This installer was only tested on Windows and it could raise errors in other operating systems. Please try it again or create an issue on GitHub.")


import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="py_telegram",
    version="1.0.0.2",
    author="Gabriel Heinzer",
    author_email="dev@gabrielheinzer.ch",
    description="This module should help you controlling the telegram bot API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/programmer372/python-telegram-api",
    packages=setuptools.find_packages(),
    # classifiers=[
        #"Programming Language :: Python :: 3",
        #"License :: OSI Approved :: MIT License",
        #"Operating System :: OS Independent",
    # ],
    python_requires=">=3.0",
    include_package_data=True
)
